;------------------------------------------------------------------------------
; This version is based on:
;
; System Management BIOS (SMBIOS) Reference Specification
; DSP0134
; Version 2.6.1 Status: DMTF Standard
; March 17, 2009
;
; Source: http://www.dmtf.org/standards/smbios
;------------------------------------------------------------------------------

;------------------------------------------------------------------------------
; Note that this file is MOSTLY INCOMPLETE, without even place holders for
; the missing components. Currently, only the BIOS Information (Type 0),
; System Information (Type 1), and Processor Information (Type 4)
; structures are included, and even for these there are some missing
; components.
;------------------------------------------------------------------------------

;------------------------------------------------------------------------------
; Applicable for non-EFI systems that support the table-based access method
; for the SMBIOS structures, first defined in version 2.1 of the SMBIOS
; standard, released 06/16/1997.
;------------------------------------------------------------------------------

;------------------------------------------------------------------------------
; SMBIOS Structure Table Entry Point Structure.
;------------------------------------------------------------------------------

SMB_ENTRY_POINT_STRUCTURE struct
  epsAnchorString       db 4 dup(?)       ; '_SM_'
  epsChecksum           db ?
  epsLength             db ?
  smbMajorVersion       db ?
  smbMinorVersion       db ?
  maxStructureSize      dw ?
  epRevision            db ?
  formattedArea         db 5 dup(?)
  ;; Start of Intermediate Entry Point Structure (DMI).
  iepsAnchorString      db 5 dup(?)       ; '_DMI_'
  iepsChecksum          db ?
  structureTableLength  dw ?
  structureTableAddress dd ?
  numberOfStructures    dw ?
  bcdRevision           db ?
SMB_ENTRY_POINT_STRUCTURE ends

;----------------------------------------------------------
; Four-byte header that each SMBIOS structure begins with.
;----------------------------------------------------------

SMB_STRUCTURE_HEADER struct
  structureType   db ?        ; see following type equates
  formattedLength db ?        ; length of formatted portion of structure
  structureHandle dw ?        ; a unique 16-bit number
SMB_STRUCTURE_HEADER ends

;----------------------------------------------------------
; Type equates for the required structures (SMBIOS v2.3+).
;----------------------------------------------------------

SMB_TYPE_BIOS_INFO                    equ 0
SMB_TYPE_SYSTEM_INFO                  equ 1
SMB_TYPE_SYSTEM_ENCLOSURE             equ 3
SMB_TYPE_PROCESSOR_INFO               equ 4
SMB_TYPE_CACHE_INFO                   equ 7
SMB_TYPE_SYSTEM_SLOTS                 equ 9
SMB_TYPE_PHYSICAL_MEMORY_ARRAY        equ 16
SMB_TYPE_MEMORY_DEVICE                equ 17
SMB_TYPE_MEMORY_ARRAY_MAPPED_ADDRESS  equ 19
SMB_TYPE_SYSTEM_BOOT_INFO             equ 32

;------------------------------------
; Necessary additional type equates.
;------------------------------------

SMB_TYPE_INACTIVE                     equ 126
SMB_TYPE_END_OF_TABLE                 equ 127

;----------------------------------------------------
; Selected SMBIOS structures and associated equates.
;----------------------------------------------------

;------------------------------------------------------------------------
; Note that the member names that end with '$' indicate that the member
; stores the index of a string. The strings associated with the structure
; are appended after the formatted portion of the structure. Each string
; is terminated with a null and the last string with a double null.
;------------------------------------------------------------------------

;----------------------------------------------------------------------
; BIOS Information (Type 0) Structure for SMBIOS versions 2.1 to 2.4+.
;
; The members following the biCharBits member (and possibly other
; future members) may or may not be present, depending on the value
; of the formattedLength member of the header.
;----------------------------------------------------------------------

SMB_BIOS_INFO struct
  biHeader            SMB_STRUCTURE_HEADER <>
  biVendor$           db ?
  biVersion$          db ?
  biStartSeg          dw ?
  biReleaseDate$      db ?
  biRomSize           db ?
  biCharBits          dq ?
  biExtByte1          db ?
  biExtByte2          db ?
  biSystemBIOSMajor   db ?
  biSystemBIOSMinor   db ?
  biCtrlFirmwareMajor db ?
  biCtrlFirmwareMinor db ?
SMB_BIOS_INFO ends

;-------------------------------------------------------
; Equates for BIOS Characteristics (biCharBits) member.
;-------------------------------------------------------

BICHARBITS_UNKNOWN        equ 4
BICHARBITS_NOT_SUPPORTED  equ 8
BICHARBITS_ISA            equ 10h
BICHARBITS_MCA            equ 20h
BICHARBITS_EISA           equ 40h
BICHARBITS_PCI            equ 80h
BICHARBITS_PCCARD         equ 100h
BICHARBITS_PNP            equ 200h
BICHARBITS_APM            equ 400h
BICHARBITS_FLASH          equ 800h
BICHARBITS_SHADOW         equ 1000h
BICHARBITS_VESA           equ 2000h
BICHARBITS_ESCD           equ 4000h
BICHARBITS_BOOTCD         equ 8000h
BICHARBITS_BOOTSEL        equ 10000h
BICHARBITS_ROMSOCKET      equ 20000h
BICHARBITS_BOOTCARD       equ 40000h
BICHARBITS_EDD            equ 80000h
BICHARBITS_INT13_NEC12    equ 100000h
BICHARBITS_INT13_TOS12    equ 200000h
BICHARBITS_INT13_360      equ 400000h
BICHARBITS_INT13_12       equ 800000h
BICHARBITS_INT13_720      equ 1000000h
BICHARBITS_INT13_288      equ 2000000h
BICHARBITS_INT5           equ 4000000h
BICHARBITS_INT9           equ 8000000h
BICHARBITS_INT14          equ 10000000h
BICHARBITS_INT17          equ 20000000h
BICHARBITS_INT10_CGA_MONO equ 40000000h
BICHARBITS_NECPC98        equ 80000000h

;------------------------------------------------------------------------
; Equates for BIOS Characteristics Extension Byte 1 (biExtByte1) member.
;------------------------------------------------------------------------

BIEXTBYTE1_ACPI         equ 1
BIEXTBYTE1_USBLEGACY    equ 2
BIEXTBYTE1_AGP          equ 4
BIEXTBYTE1_BOOTI2O      equ 8
BIEXTBYTE1_BOOTLS120    equ 10h
BIEXTBYTE1_BOOTATAPIZIP equ 20h
BIEXTBYTE1_BOOT1394     equ 40h
BIEXTBYTE1_SMARTBATTERY equ 80h

;----------------------------------------
; System Information (Type 1) Structure.
;----------------------------------------

SMB_SYSTEM_INFO struct
  header        SMB_STRUCTURE_HEADER <>
  manufacturer$ db ?
  productName$  db ?
  version$      db ?
  serialNumber$ db ?
  uuid          db 16 dup(?)    ; 2.1+
  wakeUpType    db ?            ; 2.1+
  skuNumber$    db ?            ; 2.4+
  family$       db ?            ; 2.4+
SMB_SYSTEM_INFO ends

;------------------------------------------------
; Equates for Wake-Up Type (wakeUpType) emember.
;------------------------------------------------

SIWAKE_UP_TYPE_OTHER          equ 1
SIWAKE_UP_TYPE_UNKNOWN        equ 2
SIWAKE_UP_TYPE_APM            equ 3
SIWAKE_UP_TYPE_MODEM          equ 4
SIWAKE_UP_TYPE_LAN            equ 5
SIWAKE_UP_TYPE_POWER_SWITCH   equ 6
SIWAKE_UP_TYPE_PCI            equ 7
SIWAKE_UP_TYPE_POWER_RESTORED equ 8

;-------------------------------------------
; Processor Information (Type 4) Structure.
;-------------------------------------------

SMB_PROCESSOR_INFO struct
  piHeader        SMB_STRUCTURE_HEADER <>
  piSocket$       db ?
  piType          db ?
  piFamily        db ?
  piManufacturer$ db ?
  piID            dq ?
  piVersion$      db ?
  piVoltage       db ?
  piExtClock      dw ?
  piMaxSpeed      dw ?
  piCurrentSpeed  dw ?
  piStatus        db ?
  piUpgrade       db ?
  piCacheHandleL1 dw ?
  piCacheHandleL2 dw ?
  piCacheHandleL3 dw ?
  piSN$           db ?
  piAssetTag$     db ?
  piPN$           db ?
  piCoreCount     db ?
  piEnabledCount  db ?
  piThreadCount   db ?
  piChars         dw ?
  piFamily2       dw ?
SMB_PROCESSOR_INFO ends

;---------------------------------------------
; Equates for Processor Type (piType) member.
;---------------------------------------------

PITYPE_OTHER   equ 1
PITYPE_UNKNOWN equ 2
PITYPE_CENTRAL equ 3
PITYPE_MATH    equ 4
PITYPE_DSP     equ 5
PITYPE_VIDEO   equ 6

;-------------------------------------------------------------------------
; This indicator, returned in the Processor Family (piFamily) member,
; specifies that the processor family should be obtained from the
; Processor Family 2 (piFamily2) member.
;-------------------------------------------------------------------------

USEPF2 equ 254

;----------------------------------------------------------------------
; A set of strings corresponding to the values in the Processor Family
; (piFamily) and Processor Family2 (piFamily2) members (x86/87-related
; only) are in a string table defined in rsrc.rc.
;----------------------------------------------------------------------
